
# Type: has chemical formula


description of chemical compound based on element symbols

URI: [biolink:has_chemical_formula](https://w3id.org/biolink/vocab/has_chemical_formula)


## Domain and Range

[NamedThing](NamedThing.md) ->  <sub>OPT</sub> [ChemicalFormulaValue](types/ChemicalFormulaValue.md)

## Parents

 *  is_a: [node property](node_property.md)

## Children


## Used by

 * [NamedThing](NamedThing.md)

## Other properties

|  |  |  |
| --- | --- | --- |
| **Mappings:** | | WD:P274 |

